.. _all-salt.pillars:

==============
pillar modules
==============

.. currentmodule:: salt.pillar

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cmd_json
    cmd_yaml
    cmd_yamlex
    cobbler
    confidant
    consul_pillar
    csvpillar
    django_orm
    ec2_pillar
    etcd_pillar
    file_tree
    foreman
    git_pillar
    hg_pillar
    hiera
    http_json
    http_yaml
    libvirt
    makostack
    mongo
    mysql
    neutron
    nodegroups
    pepa
    pillar_ldap
    puppet
    reclass_adapter
    redismod
    s3
    sql_base
    sqlcipher
    sqlite3
    stack
    svn_pillar
    varstack_pillar
    vault
    virtkey
